/* artistLookup.h

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#ifndef ARTISTLOOKUP_H
#define ARTISTLOOKUP_H

#include "palomaDialog.h"
#include "dataset.h"

#include <gtk--.h>
#include <string>
#include <vector>
#include <set>

class ArtistDialog;
class ArtistMergeDialog;

class ArtistLookup : public PalomaDialog {
public:
  // This is a vector of ArtistID's.  It's the set, in order, of all
  // artists in the list.
  typedef vector<int> ArtistList;

  ArtistLookup(const Dataset &data, bool edit_mode);
  ~ArtistLookup();

  TableDataProxy get_artist() const;
  const ArtistList &get_artist_list() const;

  void popup_artist_dialog(int artist_index);

  void menu_make_playlist();
  void menu_merge();

private:
  // This class is passed into artist_dialog_accepted as extra data
  // piggybacking on the ArtistDialog's "accept" event.  It indicates
  // the dialog pointer and the particular artist number the dialog was
  // associated with.
  class AcceptDialogData {
  public: 
    AcceptDialogData(ArtistDialog *dialog, int artist_index);
    ArtistDialog *_dialog;
    int _artist_index;
  };

  void ok_button_clicked();
  void edit_button_clicked();
  void cancel_button_clicked();
  gint clist_clicked(GdkEventButton *event);
  void artist_dialog_accepted(AcceptDialogData add);
  void merge_dialog_accepted(ArtistMergeDialog *dialog);

  void layout_window();

  Gtk_ItemFactory_MenuBar _menu;
  Gtk_ObjectHandle<Gtk_MenuBar> _menubar;
  Gtk_VBox _box1;
  Gtk_ScrolledWindow _artist_window;
  Gtk_CList _clist;
  Gtk_Button _ok_button;
  Gtk_Button _edit_button;
  Gtk_Button _merge_button;
  Gtk_Button _cancel_button;

  ArtistList _artist_list;

  bool _edit_mode;
};

#endif

